/**
 * This higher-order component is used to render the Error page if a HTTP status
 * code >400 is thrown by one of the pages.
 *
 * To trigger it, just add statusCode to the object returned by getInitialProps
 *
 * This solution is based on Tim Neutkens's insights and inspired by Nuxt.js
 * https://spectrum.chat/next-js/general/error-handling-in-async-getinitialprops~99400c6c-0da8-4de5-aecd-2ecf122e8ad0
 * https://github.com/nuxt/nuxt.js/issues/895#issuecomment-308682972
 */
import React from 'react';
import ErrorPage from 'next/error';
import { default as NextApp, NextAppContext, AppProps, DefaultAppIProps } from 'next/app';
export interface WithErrorProps {
    error?: {
        statusCode: number;
        [key: string]: any;
    };
}
interface AppInitialProps {
    pageProps: WithErrorProps;
}
declare const withError: (Error?: typeof ErrorPage) => <P extends WithErrorProps>(WrappedComponent: typeof NextApp) => {
    new (props: Readonly<P & WithErrorProps & AppProps<Record<string, string | string[] | undefined>, {}> & DefaultAppIProps>): {
        render(): JSX.Element;
        context: any;
        setState<K extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<P & WithErrorProps & AppProps<Record<string, string | string[] | undefined>, {}> & DefaultAppIProps>) => {} | Pick<{}, K> | null) | Pick<{}, K> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callBack?: (() => void) | undefined): void;
        readonly props: Readonly<P & WithErrorProps & AppProps<Record<string, string | string[] | undefined>, {}> & DefaultAppIProps> & Readonly<{
            children?: React.ReactNode;
        }>;
        state: Readonly<{}>;
        refs: {
            [key: string]: React.ReactInstance;
        };
    };
    new (props: P & WithErrorProps & AppProps<Record<string, string | string[] | undefined>, {}> & DefaultAppIProps, context?: any): {
        render(): JSX.Element;
        context: any;
        setState<K extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<P & WithErrorProps & AppProps<Record<string, string | string[] | undefined>, {}> & DefaultAppIProps>) => {} | Pick<{}, K> | null) | Pick<{}, K> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callBack?: (() => void) | undefined): void;
        readonly props: Readonly<P & WithErrorProps & AppProps<Record<string, string | string[] | undefined>, {}> & DefaultAppIProps> & Readonly<{
            children?: React.ReactNode;
        }>;
        state: Readonly<{}>;
        refs: {
            [key: string]: React.ReactInstance;
        };
    };
    getInitialProps: (appContext: NextAppContext<Record<string, string | string[] | undefined>, {}>) => Promise<AppInitialProps>;
    contextType?: React.Context<any> | undefined;
};
export default withError;
